

/*
This is a UI file (.ui.qml) that is intended to be edited in Qt Design Studio only.
It is supposed to be strictly declarative and only uses a subset of QML. If you edit
this file manually, you might introduce QML code that is not supported by Qt Design Studio.
Check out https://doc.qt.io/qtcreator/creator-quick-ui-forms.html for details on .ui.qml files.
*/
import QtQuick
import QtQuick.Controls
import QtQuick3D
import QtQuick3D.Effects
import QtQuick3D.Helpers
import Flashlight
import Quick3DAssets.Flashlight
import QtQuick.Timeline 1.0
import ComponentBundles.MaterialBundle 1.0
import Effects.Glow 1.0
import QtQuick.Layouts

Rectangle {
    id: rectangle
    width: Constants.width
    height: Constants.height

    color: Constants.backgroundColor

    View3D {
        id: view3D
        anchors.fill: parent

        environment: sceneEnvironment

        ExtendedSceneEnvironment {
            id: sceneEnvironment
            glowBlendMode: comboBoxBlendMode.currentIndex === 0 ? ExtendedSceneEnvironment.GlowBlendMode.Additive : comboBoxBlendMode.currentIndex === 1 ? ExtendedSceneEnvironment.GlowBlendMode.Screen : comboBoxBlendMode.currentIndex === 2 ? ExtendedSceneEnvironment.GlowBlendMode.SoftLight : comboBoxBlendMode.currentIndex === 3 ? ExtendedSceneEnvironment.GlowBlendMode.Replace : null
            probeOrientation.y: slider_hdr_rotation.value
            glowLevel: (checkBox.checked ? ExtendedSceneEnvironment.GlowLevel.One : 0)
                       | (checkBox1.checked ? ExtendedSceneEnvironment.GlowLevel.Two : 0)
                       | (checkBox2.checked ? ExtendedSceneEnvironment.GlowLevel.Three : 0)
                       | (checkBox3.checked ? ExtendedSceneEnvironment.GlowLevel.Four : 0)
                       | (checkBox4.checked ? ExtendedSceneEnvironment.GlowLevel.Five : 0)
                       | (checkBox5.checked ? ExtendedSceneEnvironment.GlowLevel.Six : 0)
                       | (checkBox6.checked ? ExtendedSceneEnvironment.GlowLevel.Seven : 0)
            probeExposure: slider_hdr_strength.value
            glowBloom: slider_bloom.value
            glowIntensity: slider_intensity.value
            glowStrength: slider_strength.value
            glowUseBicubicUpscale: switchBicubicUpsampling.checked
            glowHDRScale: 1
            lutEnabled: false
            skyboxBlurAmount: 0
            depthOfFieldFocusDistance: 600
            depthOfFieldBlurAmount: 10
            depthOfFieldFocusRange: 1
            depthOfFieldEnabled: false
            aoStrength: 100
            aoEnabled: false
            lensFlareGhostDispersal: 0.2
            lensFlareBloomBias: 0.2
            lensFlareBloomScale: 1
            lensFlareEnabled: false
            clearColor: "#0d0d0d"
            glowHDRMaximumValue: 10
            glowHDRMinimumValue: 1
            backgroundMode: SceneEnvironment.SkyBox
            lightProbe: moonless_golf_4k
            glowQualityHigh: true
            glowEnabled: true
            antialiasingMode: SceneEnvironment.SSAA
            antialiasingQuality: SceneEnvironment.VeryHigh
        }

        Node {
            id: scene

            PerspectiveCamera {
                id: sceneCamera
                fieldOfView: 30
                z: 350
            }

            Flashlight {
                id: flashlight
                property0: slider_lamp_brightness
                x: 51
                y: 13
                eulerRotation.y: 45
                eulerRotation.z: 17.54678
                eulerRotation.x: 0
                scale.z: 10
                scale.y: 10
                scale.x: 10
                z: 0
            }
        }
    }

    ColumnLayout {
        id: controlsID
        anchors.left: parent.left
        anchors.top: parent.top
        anchors.leftMargin: 24
        anchors.topMargin: 24
        spacing: 24
        Pane {
            id: pane_lamp
            background: null
            Column {
                id: columnLampBrightness
                Text {
                    id: lampBrightnessTextID
                    color: "#ffffff"
                    text: qsTr("Lamp brightness")
                    font.pixelSize: 18
                    wrapMode: Text.NoWrap
                }
                Row {
                    id: row
                    spacing: 8
                    Slider {
                        id: slider_lamp_brightness
                        value: 0
                        to: 0
                        from: 1000
                    }
                    Text {
                        id: lampBrightnessValueID
                        color: "#ffffff"
                        text: 1000 - (slider_lamp_brightness.value).toFixed(0)
                        anchors.verticalCenter: parent.verticalCenter
                        font.pixelSize: 18
                    }
                }
            }
        }

        Pane {
            id: pane_hdr

            spacing: 24
            background: null
            ColumnLayout {
                Column {
                    id: columnHDRBrightness

                    Text {
                        id: environmentBrightnessLabelID
                        width: 150
                        color: "#ffffff"
                        text: qsTr("Environment brightness")
                        font.pixelSize: 18
                        wrapMode: Text.NoWrap
                    }
                    Row {
                        spacing: 8
                        Slider {
                            id: slider_hdr_strength
                            value: 0.3
                            stepSize: 0.01
                            to: 10
                        }
                        Text {
                            id: environmentBrightnessValueID
                            color: "#ffffff"
                            text: (sceneEnvironment.probeExposure).toFixed(2)
                            font.pixelSize: 18
                        }
                    }
                }
                Column {
                    id: columnHDRRotation
                    Text {
                        id: environmentRotationLabelID
                        width: 150
                        color: "#ffffff"
                        text: qsTr("Environment rotation")
                        font.pixelSize: 18
                        wrapMode: Text.NoWrap
                    }
                    Row {

                        Slider {
                            id: slider_hdr_rotation
                            value: 0
                            stepSize: 15
                            to: 360
                        }
                        Text {
                            id: environmentRotationValueID
                            color: "#ffffff"
                            text: slider_hdr_rotation.value.toFixed(2)
                            font.pixelSize: 18
                        }
                    }
                }
            }
        }

        Pane {
            id: pane_glow
            background: null

            Column {
                id: columnGlow
                spacing: 10
                Text {
                    id: textGlowStrength
                    color: "#ffffff"
                    text: qsTr("Glow strength")
                    font.pixelSize: 18
                    wrapMode: Text.NoWrap
                }
                Row {
                    Slider {
                        id: slider_strength
                        value: 0.8
                        stepSize: 0.01
                        to: 2
                    }

                    Text {
                        id: textGlowStrengthValue
                        color: "#ffffff"
                        text: (sceneEnvironment.glowStrength).toFixed(2)
                        font.pixelSize: 18
                    }
                }
                Text {
                    id: textGlowIntensityLabel
                    color: "#ffffff"
                    text: qsTr("Glow intensity")
                    font.pixelSize: 18
                    wrapMode: Text.NoWrap
                }
                Row {
                    Slider {
                        id: slider_intensity
                        value: 2
                        stepSize: 0.01
                        to: 2
                    }

                    Text {
                        id: textGlowIntensityValue

                        color: "#ffffff"
                        text: (sceneEnvironment.glowIntensity).toFixed(2)
                        font.pixelSize: 18
                    }
                }

                Text {
                    id: text4
                    color: "#ffffff"
                    text: qsTr("Glow bloom")
                    font.pixelSize: 18
                    wrapMode: Text.NoWrap
                }
                Row {
                    Slider {
                        id: slider_bloom
                        value: 0.2
                        stepSize: 0.01
                    }

                    Text {
                        id: text9
                        color: "#ffffff"
                        text: (sceneEnvironment.glowBloom).toFixed(2)
                        font.pixelSize: 18
                    }
                }

                Switch {
                    id: switchBicubicUpsampling
                    text: qsTr("Bicubic Upsampling")
                    checkable: true
                    checked: false
                }
            }
        }

        Pane {
            id: pane_levels
            background: null

            Column {
                id: columnLevels

                Text {
                    id: text5
                    color: "#ffffff"
                    text: qsTr("Blur levels")
                    font.pixelSize: 18
                    wrapMode: Text.NoWrap
                }

                Grid {
                    id: grid
                    rows: 2
                    columns: 4

                    CheckBox {
                        id: checkBox
                        text: qsTr("1")
                        checked: true
                    }

                    CheckBox {
                        id: checkBox1
                        text: qsTr("2")
                        checked: true
                    }

                    CheckBox {
                        id: checkBox2
                        text: qsTr("3")
                        checked: true
                    }

                    CheckBox {
                        id: checkBox3
                        text: qsTr("4")
                        checked: true
                    }

                    CheckBox {
                        id: checkBox4
                        text: qsTr("5")
                        checked: true
                    }

                    CheckBox {
                        id: checkBox5
                        text: qsTr("6")
                        checked: true
                    }

                    CheckBox {
                        id: checkBox6
                        text: qsTr("7")
                        checked: true
                    }
                }
            }
        }

        Pane {
            id: pane_blend
            background: null

            Column {
                id: columnBlend
                width: 200
                height: 400

                Text {
                    id: text6
                    color: "#ffffff"
                    text: qsTr("Blend mode")
                    font.pixelSize: 18
                    wrapMode: Text.NoWrap
                }

                ComboBox {
                    id: comboBoxBlendMode
                    model: ["Additive", "Screen", "Soft Light", "Replace"]
                    displayText: model[comboBoxBlendMode.currentIndex]
                }
            }
        }
    }

    Item {
        id: __materialLibrary__
        PrincipledMaterial {
            id: defaultMaterial
            roughness: 0.5
            objectName: "Default Material"
            baseColor: "#4aee45"
        }

        Texture {
            id: moonless_golf_4k
            source: "images/moonless_golf_4k.hdr"
        }

        Texture {
            id: basicLights3_4K
            source: "images/BasicLights3_4K.hdr"
        }
    }

    Timeline {
        id: timeline
        animations: [
            TimelineAnimation {
                id: timelineAnimation
                running: true
                loops: 1
                duration: 1000
                to: 1000
                from: 0
            }
        ]
        startFrame: 0
        endFrame: 1000
        enabled: true
    }
}

/*##^##
Designer {
    D{i:0}D{i:3;cameraSpeed3d:25;cameraSpeed3dMultiplier:1}D{i:53}
}
##^##*/

